pub struct GammaLutBuilder { /* private fields */ }Expand description
Implementations
Sourceimpl GammaLutBuilder
impl GammaLutBuilder
Sourcepub const fn new_power_fn(gamma: f64) -> GammaLutBuilder
pub const fn new_power_fn(gamma: f64) -> GammaLutBuilder
Create a builder for a simple power function with gamma as the exponent.
Sourcepub fn new_piecewise_fn(
linear_slope: f64,
linear_end: f64,
gamma: f64,
) -> GammaLutBuilder
pub fn new_piecewise_fn( linear_slope: f64, linear_end: f64, gamma: f64, ) -> GammaLutBuilder
Create a builder for a piecewise power function with gamma as the
exponent.
The arguments correspond to these values in a linear (x) to non-linear
(x') transfer function:
S = linear_slope
L = linear_end
G = gamma
x' = S * x x <= L
k1 * x ^ (1/G) + k2 x > Lwhere k1 and k2 are derived constants.
Sourcepub fn u8_to_linear_entries(&self) -> impl ExactSizeIterator
pub fn u8_to_linear_entries(&self) -> impl ExactSizeIterator
Returns the table entries for an encoded u8 to linear float table.
Sourcepub fn u16_to_linear_entries(&self) -> impl ExactSizeIterator
pub fn u16_to_linear_entries(&self) -> impl ExactSizeIterator
Returns the table entries for an encoded u16 to linear float table.